.. _features:

================
 SymPy Features
================

This section discusses the common and advanced SymPy operations and features.

**Content**

.. toctree::
   :maxdepth: 2

   basic_operations.rst
   printing.rst
   simplification.rst
   calculus.rst
   solvers.rst
   matrices.rst
   manipulation.rst
